@@ -1,6 +1,6 @@
 package Workflow;
 
-# $Id: Workflow.pm 501 2009-12-27 14:31:51Z jonasbn $
+# $Id: Workflow.pm 535 2010-11-14 18:49:25Z jonasbn $
 
 use warnings;
 use strict;
@@ -15,7 +15,7 @@ use English qw( -no_match_vars );
 my @FIELDS = qw( id type description state last_update time_zone );
 __PACKAGE__->mk_accessors(@FIELDS);
 
-$Workflow::VERSION = '1.33_8';
+$Workflow::VERSION = '1.34_1';
 
 use constant NO_CHANGE_VALUE => 'NOCHANGE';
 
@@ -481,6 +481,44 @@ This documentation describes version 0.15 of Workflow
  my $workflow = FACTORY->fetch_workflow( 'myworkflow', $id );
  print "Current state: ", $workflow->state, "\n";
 
+=head1 QUICK START
+
+The F<eg/ticket/> directory contains a configured workflow system. 
+You can access the same data and logic in two ways:
+
+=over
+
+=item * a command-line application (ticket.pl)
+
+=item * a CGI script               (ticket.cgi)
+
+=item * a web application          (ticket_web.pl)
+
+=back
+
+To initialize:
+
+	perl ticket.pl --db
+
+To run the command-line application:
+
+	perl ticket.pl
+
+To access the database and data from CGI, add the relevant
+configuration for your web server and call ticket.cgi:
+
+	http://www.mysite.com/workflow/ticket.cgi
+
+To start up the standalone web server:
+
+	perl ticket_web.pl
+
+(Barring changes to HTTP::Daemon and forking the standalone server
+won't work on Win32; use CGI instead, although patches are always
+welcome.)
+
+For more info, see F<eg/ticket/README>
+
 =head1 DESCRIPTION
 
 =head2 Overview
@@ -1097,6 +1135,33 @@ to L<Workflow::Config>, for implementation details.
 
 =back
 
+=head2 DEPENDENCIES FOR THE EXAMPLE APPLICATION
+
+=over
+
+=item L<CGI>
+
+=item L<CGI::Cookie>
+
+=item L<DBD::SQLite>
+
+=item L<HTTP::Daemon>
+
+=item L<HTTP::Request>
+
+=item L<HTTP::Response>
+
+=item L<HTTP::Status>
+
+=item L<Template> (Template Toolkit)
+
+=back
+
+For Win32 systems you can get the Template Toolkit and DBD::SQLite
+PPDs from TheoryX:
+
+	L<http://theoryx5.uwinnipeg.ca/cgi-bin/ppmserver?urn:/PPMServer58>
+
 =head1 INCOMPATIBILITIES
 
 No special incompatibilies exist, CPAN testers reports however do demonstrate
@@ -1269,7 +1334,7 @@ development. The list is low-traffic.
 
 =over
 
-=item L<http://sourceforge.net/mail/?group_id=177533>
+=item L<http://sourceforge.net/mail/?group_id=177533> (including archive)
 
 =back
 
@@ -1281,7 +1346,8 @@ development. The list is low-traffic.
 
 =item Ohloh news L<https://www.ohloh.net/p/perl-Workflow/messages.rss>
 
-=item CPAN testers reports L<http://cpantesters.perl.org/show/Workflow.rss>
+=item CPAN testers reports L<http://cpantesters.perl.org/show/Workflow.rss> in matrix:
+
 
 =back
 
@@ -1305,13 +1371,24 @@ L<http://search.cpan.org/dist/Workflow>
 
 =head1 SEE ALSO
 
-October 2004 talk 'Workflows in Perl' given to
-pgh.pm: L<http://www.cwinters.com/pdf/workflow_pgh_pm.pdf>
+=over
+
+* November 2010 talk 'Workflow' given at Nordic Perl Workshop 2010 in Reykjavik,
+Iceland by jonasbn 
+L<http://www.slideshare.net/jonasbn/workflow-npw2010>
+
+* August 2010 talk 'Workflow' given at YAPC::Europe 2010 in Pisa, Italy by jonasbn 
+L<http://www.slideshare.net/jonasbn/workflow-yapceu2010>
+
+* October 2004 talk 'Workflows in Perl' given to
+pgh.pm by Chris Winters: L<http://www.cwinters.com/pdf/workflow_pgh_pm.pdf>
+
+=back
 
 =head1 COPYRIGHT
 
 Copyright (c) 2003 Chris Winters and Arvato Direct;
-Copyright (c) 2004-2008 Chris Winters. All rights reserved.
+Copyright (c) 2004-2010 Chris Winters. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
@@ -1324,18 +1401,23 @@ Chris Winters E<lt>chris@cwinters.comE<gt>, original author.
 
 The following folks have also helped out:
 
-<<<<<<< .working
-Danny Sadinoff, patches to give better control of initial state and history 
-records for workflow
+Steven van der Vegt, patch for autorun in initial state and improved exception
+handling for validators, see Changes file: 1.34_1
 
-=======
-Thomas Erskine, for patch adding new accessors and fixing several bugs
+Andrew O'Brien, patch implementing dynamic reloaded of flows, see Changes file:
+1.33
 
->>>>>>> .merge-right.r488
-Ivan Paponov, for patch implementing action groups, See Changes file, 0.32_7
+Sergei Vyshenski, bug reports - addressed and included in 1.33 
 
-Robert Stockdale, for patch implementing dynamic names for conditions,
-See Changes file, 0.32_6
+Alejandro Imass, improvements and clarifications, see Changes file: 1.33
+
+Danny Sadinoff, patches to give better control of initial state and history records for workflow, see Changes file: 1.33
+
+Thomas Erskine, for patch adding new accessors and fixing several bugs see Changes file 1.33
+
+Ivan Paponov, for patch implementing action groups, see Changes file, 1.33
+
+Robert Stockdale, for patch implementing dynamic names for conditions, see Changes file, 1.32
 
 Jim Brandt, for patch to Workflow::Config::XML. See Changes file, 0.27 and 0.30
 
@@ -1369,3 +1451,5 @@ to subclass L<Workflow::Factory>) and good ideas.
 
 Martin Winkler E<lt>mw@arsnavigandi.deE<gt> - Pointed out a bug and a
 few other items.
+
+=cut
