@@ -1,6 +1,6 @@
 package Workflow::Factory;
 
-# $Id: Factory.pm 500 2009-12-27 14:07:48Z jonasbn $
+# $Id: Factory.pm 536 2010-11-14 18:53:30Z jonasbn $
 
 use warnings;
 use strict;
@@ -11,7 +11,7 @@ use Workflow::Exception qw( configuration_error workflow_error );
 use Carp qw(croak);
 use English qw( -no_match_vars );
 
-$Workflow::Factory::VERSION = '1.19';
+$Workflow::Factory::VERSION = '1.20';
 
 my ($log);
 my (%INSTANCES);
@@ -92,7 +92,7 @@ sub _initialize_instance {
 
 sub _delete_instance {
     my ($class) = @_;
-    my $log ||= get_logger();
+    $log ||= get_logger();
 
     if ( $INSTANCES{$class} ) {
         $log->is_debug
@@ -326,17 +326,19 @@ sub _load_class {
 }
 
 sub create_workflow {
-    my ( $self, $wf_type ) = @_;
+    my ( $self, $wf_type, $context ) = @_;
     $log ||= get_logger();
 
     my $wf_config = $self->_get_workflow_config($wf_type);
     unless ($wf_config) {
         workflow_error "No workflow of type '$wf_type' available";
     }
-    
-    my $wf = Workflow->new( undef, $wf_config->{initial_state}|| $DEFAULT_INITIAL_STATE, $wf_config,
-        $self->{_workflow_state}{$wf_type} );
-    $wf->context( Workflow::Context->new );
+
+    my $wf
+        = Workflow->new( undef,
+        $wf_config->{initial_state} || $DEFAULT_INITIAL_STATE,
+        $wf_config, $self->{_workflow_state}{$wf_type} );
+    $wf->context( $context || Workflow::Context->new );
     $wf->last_update( DateTime->now( time_zone => $wf->time_zone() ) );
     $log->is_info
         && $log->info("Instantiated workflow object properly, persisting...");
@@ -363,6 +365,13 @@ sub create_workflow {
 
     $self->_commit_transaction($wf);
 
+    my $state = $wf->_get_workflow_state();
+    if ( $state->autorun ) {
+        $log->is_info && $log->info( "State '$state' marked to be run ",
+            "automatically; executing that state/action..." );
+        $wf->_auto_execute_state($state);
+    }
+
     $self->associate_observers_with_workflow($wf);
     $wf->notify_observers('create');
 
@@ -370,7 +379,7 @@ sub create_workflow {
 }
 
 sub fetch_workflow {
-    my ( $self, $wf_type, $wf_id ) = @_;
+    my ( $self, $wf_type, $wf_id, $context ) = @_;
     $log ||= get_logger();
 
     my $wf_config = $self->_get_workflow_config($wf_type);
@@ -389,7 +398,8 @@ sub fetch_workflow {
         );
     my $wf = Workflow->new( $wf_id, $wf_info->{state}, $wf_config,
         $self->{_workflow_state}{$wf_type} );
-	$wf->context( Workflow::Context->new ) if (not $wf->context());
+    $wf->context( $context || Workflow::Context->new )
+        if ( not $wf->context() );
     $wf->last_update( $wf_info->{last_update} );
 
     $persister->fetch_extra_workflow_data($wf);
@@ -408,18 +418,19 @@ sub associate_observers_with_workflow {
 }
 
 sub _initialize_workflow_config {
-    my $self = shift;
+    my $self    = shift;
     my $wf_type = shift;
     $log ||= get_logger();
-    if ( ref($self->config_callback) eq 'CODE' ) {
-        my $args = &{ $self->config_callback }( $wf_type );
-        $self->add_config_from_file( %$args ) if $args && %$args;
+    if ( ref( $self->config_callback ) eq 'CODE' ) {
+        my $args = &{ $self->config_callback }($wf_type);
+        $self->add_config_from_file( %{$args} ) if $args && %{$args};
     }
 }
 
 sub _get_workflow_config {
     my ( $self, $wf_type ) = @_;
-    $self->_initialize_workflow_config( $wf_type ) unless $self->{_workflow_config}{ $wf_type };
+    $self->_initialize_workflow_config($wf_type)
+        unless $self->{_workflow_config}{$wf_type};
     return $self->{_workflow_config}{$wf_type};
 }
 
@@ -513,14 +524,14 @@ sub _add_action_config {
         # process?
         my $type = exists $actions->{type} ? $actions->{type} : 'default';
 
-        my $a;
+        my $action;
         if ( exists $actions->{action} ) {
-            $a = $actions->{action};
+            $action = $actions->{action};
         } else {
-            push @{$a}, $actions;
+            push @{$action}, $actions;
         }
 
-        foreach my $action_config ( @{$a} ) {
+        foreach my $action_config ( @{$action} ) {
             my $name = $action_config->{name};
             $log->is_debug
                 && $log->debug(
@@ -618,8 +629,8 @@ sub get_persister {
 }
 
 sub get_persisters {
-    my $self = shift;
-    my @persisters = sort keys %{$self->{_persister}};
+    my $self       = shift;
+    my @persisters = sort keys %{ $self->{_persister} };
 
     return @persisters;
 }
@@ -629,7 +640,7 @@ sub get_persister_for_workflow_type {
 
     my ($type) = @_;
     my $wf_config = $self->_get_workflow_config($type);
-    if (not $wf_config) {
+    if ( not $wf_config ) {
         workflow_error "no workflow of type '$type' available";
     }
     my $persister = $self->get_persister( $wf_config->{'persister'} );
@@ -777,8 +788,8 @@ sub get_validator {
 }
 
 sub get_validators {
-    my $self = shift;
-    my @validators = sort keys %{$self->{_validators}};
+    my $self       = shift;
+    my @validators = sort keys %{ $self->{_validators} };
     return @validators;
 }
 
@@ -1161,7 +1172,7 @@ L<Workflow::Validator>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003-2007 Chris Winters. All rights reserved.
+Copyright (c) 2003-2010 Chris Winters. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
@@ -1170,6 +1181,6 @@ it under the same terms as Perl itself.
 
 Jonas B. Nielsen (jonasbn) E<lt>jonasbn@cpan.orgE<gt> is the current maintainer.
 
-Chris Winters E<lt>chris@cwinters.comE<gt>, original author.
+Chris Winters E <lt> chris @cwinters . comE <gt>, original author .
 
 =cut
