@@ -1,6 +1,6 @@
 package Workflow::State;
 
-# $Id: State.pm 500 2009-12-27 14:07:48Z jonasbn $
+# $Id: State.pm 530 2010-08-07 18:06:03Z jonasbn $
 
 use warnings;
 use strict;
@@ -48,11 +48,12 @@ sub get_available_action_names {
     $self->clear_condition_cache();
 
     foreach my $action_name (@all_actions) {
-        #my $action_group = FACTORY->{_action_config}{$action_name}{'group'};
 
-		#From Ivan Paponov
-		my $action_group = FACTORY->{_action_config}{$self->type()}{$action_name}{'group'};
-		
+        #From Ivan Paponov
+        my $action_group
+            = FACTORY->{_action_config}{ $self->type() }{$action_name}
+            {'group'};
+
         if ( defined $group && length $group ) {
             if ( $action_group ne $group ) {
                 next;
@@ -410,8 +411,8 @@ sub _get_next_condition_count {
     my ($self) = @_;
 
     # Initialize if not set.
-    my $count =
-        defined $self->_test_condition_count()
+    my $count
+        = defined $self->_test_condition_count()
         ? $self->_test_condition_count() + 1
         : 1;
 
